pub enum InternalPeerID<A> {
KnownAddr(A),
Unknown([u8; 16]),
}Expand description
An internal identifier for a given peer, will be their address if known or a random u128 if not.
Variants
KnownAddr(A)
A known address.
Unknown([u8; 16])
An unknown address (probably an inbound anonymity network connection).