pub struct Client<Z: NetworkZone> {
pub info: PeerInformation<Z::Addr>,
/* private fields */
}Expand description
This represents a connection to a peer.
It allows sending requests to the peer, but does only does minimal checks that the data returned is the data asked for, i.e. for a certain request the only thing checked will be that the response is the correct response for that request, not that the response contains the correct data.
Fields
info: PeerInformation<Z::Addr>Information on the connected peer.
Implementations
Sourceimpl<Z: NetworkZone> Client<Z>
impl<Z: NetworkZone> Client<Z>
Sourcepub fn ready_peer_request(&mut self) -> Ready<'_, Self, PeerRequest> ⓘ
pub fn ready_peer_request(&mut self) -> Ready<'_, Self, PeerRequest> ⓘ
Waits for the client to be ready for a PeerRequest, then returns a service to handle one.
Sourcepub fn ready_broadcast(&mut self) -> Ready<'_, Self, BroadcastMessage> ⓘ
pub fn ready_broadcast(&mut self) -> Ready<'_, Self, BroadcastMessage> ⓘ
Waits for the client to be ready for a BroadcastMessage, then returns a service to handle one.