pub struct PeerInformation<A> {
pub id: InternalPeerID<A>,
pub handle: ConnectionHandle,
pub direction: ConnectionDirection,
pub pruning_seed: PruningSeed,
pub basic_node_data: BasicNodeData,
pub core_sync_data: Arc<Mutex<CoreSyncData>>,
}Expand description
Information on a connected peer.
Fields
id: InternalPeerID<A>The internal peer ID of this peer.
handle: ConnectionHandleThe ConnectionHandle for this peer, allows banning this peer and checking if it is still
alive.
direction: ConnectionDirectionThe direction of this connection (inbound|outbound).
pruning_seed: PruningSeedThe peer’s [PruningSeed].
basic_node_data: BasicNodeDataThe peer’s [BasicNodeData].
core_sync_data: Arc<Mutex<CoreSyncData>>The CoreSyncData of this peer.
Data across fields are not necessarily related, so CoreSyncData::top_id is not always the
block hash for the block at height one below CoreSyncData::current_height.
This value is behind a Mutex and is updated whenever the peer sends new information related
to their sync state. It is publicly accessible to anyone who has a peers Client handle. You
probably should not mutate this value unless you are creating a custom ProtocolRequestHandler.