pub struct ConnectRequest<Z: NetworkZone> {
pub addr: Z::Addr,
pub permit: Option<OwnedSemaphorePermit>,
}Expand description
A request to connect to a peer.
Fields
addr: Z::AddrThe peer’s address.
permit: Option<OwnedSemaphorePermit>A permit which will be held be the connection allowing you to set limits on the number of connections.
This doesn’t have to be set.